@@ -5,59 +5,57 @@ from __future__ import unicode_literals, print_function
 # The following text entries, derived from RFC 7841, were taken from
 # https://www.rfc-editor.org/materials/status-memos.txt on 01 Feb 2018
 
-boilerplate_status_of_memo = {
+boilerplate_rfc_status_of_memo = {
     'IETF': {
         'std': {
-            'true' : ["""
+            'true' : ["""<t>
             This is an Internet Standards Track document.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document is a product of the Internet Engineering Task Force
             (IETF).  It represents the consensus of the IETF community.  It has
             received public review and has been approved for publication by
             the Internet Engineering Steering Group (IESG).  Further
             information on Internet Standards is available in Section 2 of 
             RFC 7841.
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
         },
         'bcp': {
-            'true' : [ """
+            'true' : [ """<t>
             This memo documents an Internet Best Current Practice.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document is a product of the Internet Engineering Task Force
             (IETF).  It represents the consensus of the IETF community.  It has
             received public review and has been approved for publication by
             the Internet Engineering Steering Group (IESG).  Further information
             on BCPs is available in Section 2 of RFC 7841.
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
         },
         'exp': {
-            'true' : [ """
+            'true' : [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for examination, experimental implementation, and
             evaluation.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document defines an Experimental Protocol for the Internet
             community.  This document is a product of the Internet Engineering
             Task Force (IETF).  It represents the consensus of the IETF community.
@@ -65,45 +63,43 @@ boilerplate_status_of_memo = {
             by the Internet Engineering Steering Group (IESG).  Not all documents
             approved by the IESG are candidates for any level of Internet
             Standard; see Section 2 of RFC 7841. 
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
-            'false': [ """
+            'false': [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for examination, experimental implementation, and
             evaluation.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document defines an Experimental Protocol for the Internet
             community.  This document is a product of the Internet Engineering
             Task Force (IETF).  It has been approved for publication by the
             Internet Engineering Steering Group (IESG).  Not all documents
             approved by the IESG are candidates for any level of Internet
             Standard; see Section 2 of RFC 7841. 
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
         },
         'historic': {
-            'true' : [ """
+            'true' : [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for the historical record.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document defines a Historic Document for the Internet
             community.  This document is a product of the Internet Engineering
             Task Force (IETF).  It represents the consensus of the IETF community.
@@ -111,89 +107,85 @@ boilerplate_status_of_memo = {
             the Internet Engineering Steering Group (IESG).  Not all documents
             approved by the IESG are candidates for any level of Internet
             Standard; see Section 2 of RFC 7841. 
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
-            'false': [ """
+            'false': [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for the historical record.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document defines a Historic Document for the Internet
             community.  This document is a product of the Internet Engineering Task Force
             (IETF).  It has been approved for publication by the Internet
             Engineering Steering Group (IESG).  Not all documents approved by the
             IESG are candidates for any level of Internet Standard; see Section 2
             of RFC 7841. 
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
         },
         'info': {
-            'true' : [ """
+            'true' : [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for informational purposes.  
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document is a product of the Internet Engineering Task Force
             (IETF).  It represents the consensus of the IETF community.  It has
             received public review and has been approved for publication by the
             Internet Engineering Steering Group (IESG).  Not all documents
             approved by the IESG are candidates for any level of Internet
             Standard; see Section 2 of RFC 7841. 
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
-            'false': [ """
+            'false': [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for informational purposes.  
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document is a product of the Internet Engineering Task Force
             (IETF).  It has been approved for publication by the Internet
             Engineering Steering Group (IESG).  Not all documents approved by the
             IESG are candidates for any level of Internet Standard; see Section 2
             of RFC 7841.   
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
         },
     },
     'IAB': {
         'historic': {
-            'true' : [ """
+            'true' : [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for the historical record.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document defines a Historic Document for the Internet
             community.  This document is a product of the Internet Architecture
             Board (IAB) and represents information that the IAB has deemed
@@ -201,90 +193,86 @@ boilerplate_status_of_memo = {
             Internet Architecture Board (IAB).  Documents approved for
             publication by the IAB are not candidates for any level of Internet
             Standard; see Section 2 of RFC 7841.
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
-            'false': [ """
+            'false': [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for the historical record.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document defines a Historic Document for the Internet
             community.  This document is a product of the Internet Architecture
             Board (IAB) and represents information that the IAB has deemed
             valuable to provide for permanent record.  Documents approved for
             publication by the IAB are not candidates for any level of Internet
             Standard; see Section 2 of RFC 7841.
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
         },
         'info': {
-            'true' : [ """
+            'true' : [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for informational purposes.  
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document is a product of the Internet Architecture Board
             (IAB) and represents information that the IAB has deemed valuable
             to provide for permanent record.  It represents the consensus of the Internet
             Architecture Board (IAB).  Documents approved for publication
             by the IAB are not candidates for any level of Internet Standard; see
             Section 2 of RFC 7841.
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
-            'false': [ """
+            'false': [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for informational purposes.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document is a product of the Internet Architecture Board
             (IAB) and represents information that the IAB has deemed valuable
             to provide for permanent record.  Documents approved for publication
             by the IAB are not candidates for any level of Internet Standard; see
             Section 2 of RFC 7841.
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
         },
     },
     'IRTF': {
         'exp': {
-            'true' : [ """
+            'true' : [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for examination, experimental implementation, and
             evaluation. 
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document defines an Experimental Protocol for the Internet
             community.  This document is a product of the Internet Research
             Task Force (IRTF).  The IRTF publishes the results of Internet-related
@@ -294,22 +282,21 @@ boilerplate_status_of_memo = {
             (IRTF).  Documents approved for publication by the IRSG are not a
             candidate for any level of Internet Standard; see Section 2 of RFC
             7841.
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
-            'false': [ """
+            'false': [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for examination, experimental implementation, and
             evaluation.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document defines an Experimental Protocol for the Internet
             community.  This document is a product of the Internet Research Task
             Force (IRTF).  The IRTF publishes the results of Internet-related
@@ -319,22 +306,21 @@ boilerplate_status_of_memo = {
             of the Internet Research Task Force (IRTF).  Documents approved for
             publication by the IRSG are not candidates for any level of Internet
             Standard; see Section 2 of RFC 7841.
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
-            'n/a': [ """
+            'n/a': [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for examination, experimental implementation, and
             evaluation.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document defines an Experimental Protocol for the Internet
             community.  This document is a product of the Internet Research
             Task Force (IRTF).  The IRTF publishes the results of Internet-related
@@ -342,23 +328,22 @@ boilerplate_status_of_memo = {
             suitable for deployment.  Documents approved for publication by the
             IRSG are not candidates for any level of Internet Standard; see
             Section 2 of RFC 7841.
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
         },
         'historic': {
-            'true' : [ """
+            'true' : [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for the historical record.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document defines a Historic Document for the Internet
             community.  This document is a product of the Internet Research Task Force
             (IRTF).  The IRTF publishes the results of Internet-related
@@ -367,21 +352,20 @@ boilerplate_status_of_memo = {
             the {group_name} Research Group of the Internet Research Task Force (IRTF).
             Documents approved for publication by the IRSG are not a candidate for
             any level of Internet Standard; see Section 2 of RFC 7841.
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
-            'false': [ """
+            'false': [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for the historical record.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document defines a Historic Document for the Internet community.
             This document is a product of the Internet Research Task Force
             (IRTF).  The IRTF publishes the results of Internet-related
@@ -391,21 +375,20 @@ boilerplate_status_of_memo = {
             Research Task Force (IRTF).  Documents approved for
             publication by the IRSG are not a candidate for
             any level of Internet Standard; see Section 2 of RFC 7841.
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
-            'n/a': [ """
+            'n/a': [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for the historical record.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document defines a Historic Document for the Internet
             community.  This document is a product of the Internet Research
             Task Force (IRTF).  The IRTF publishes the results of Internet-related
@@ -413,23 +396,22 @@ boilerplate_status_of_memo = {
             suitable for deployment.  Documents approved for publication by the
             IRSG are not candidates for any level of Internet Standard; see
             Section 2 of RFC 7841.
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
         },
         'info': {
-            'true' : [ """
+            'true' : [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for informational purposes.  
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document is a product of the Internet Research Task Force
             (IRTF).  The IRTF publishes the results of Internet-related
             research and development activities.  These results might not be
@@ -438,21 +420,20 @@ boilerplate_status_of_memo = {
             Documents approved for publication by the IRSG are not a
             candidate for any level of Internet Standard; see Section 2 of RFC
             7841.   
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
-            'false': [ """
+            'false': [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for informational purposes.  
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document is a product of the Internet Research Task Force
             (IRTF).  The IRTF publishes the results of Internet-related
             research and development activities.  These results might not be
@@ -460,47 +441,45 @@ boilerplate_status_of_memo = {
             members of the {group_name} Research Group of the Internet
             Research Task Force (IRTF).  Documents approved for publication by the IRSG are not a
             candidate for any level of Internet Standard; see Section 2 of RFC 7841.
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
-            'n/a': [ """
+            'n/a': [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for informational purposes.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document is a product of the Internet Research Task Force
             (IRTF).  The IRTF publishes the results of Internet-related
             research and development activities.  These results might not be
             suitable for deployment.  Documents approved for publication by the
             IRSG are not candidates for any level of Internet Standard; see
             Section 2 of RFC 7841.
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
         },
     },
     'independent': {
         'exp': {
-            'n/a' : [ """
+            'n/a' : [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for examination, experimental implementation, and
             evaluation.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document defines an Experimental Protocol for the Internet
             community.  This is a contribution to the RFC Series,
             independently of any other RFC stream.  The RFC Editor has chosen to publish this
@@ -508,27 +487,25 @@ boilerplate_status_of_memo = {
             for implementation or deployment.  Documents approved for publication
             by the RFC Editor are not candidates for any level of Internet
             Standard; see Section 2 of RFC 7841.
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
-            'false': [ """
-            """
-            ,
+            'false': [ """<t>
+            </t>""",
             ],
         },
         'historic': {
-            'n/a' : [ """
+            'n/a' : [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for the historical record.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This document defines a Historic Document for the Internet
             community.  This is a contribution to the RFC Series, independently of any
             other RFC stream.  The RFC Editor has chosen to publish this
@@ -536,42 +513,39 @@ boilerplate_status_of_memo = {
             for implementation or deployment.  Documents approved for
             publication by the RFC Editor are not candidates for any level of
             Internet Standard; see Section 2 of RFC 7841.
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
-            'false': [ """
-            """
-            ,
+            'false': [ """<t>
+            </t>""",
             ],
         },
         'info': {
-            'n/a' : [ """
+            'n/a' : [ """<t>
             This document is not an Internet Standards Track specification; it is
             published for informational purposes.
-            """,
+            </t>""",
 
-            """
+            """<t>
             This is a contribution to the RFC Series, independently of any
             other RFC stream.  The RFC Editor has chosen to publish this
             document at its discretion and makes no statement about its value
             for implementation or deployment.  Documents approved for
             publication by the RFC Editor are not candidates for any level of
             Internet Standard; see Section 2 of RFC 7841.
-            """,
+            </t>""",
 
-            """
+            """<t>
             Information about the current status of this document, any
             errata, and how to provide feedback on it may be obtained at
-            http://www.rfc-editor.org/info/rfc{rfc_number}.
-            """
-            ,
+            <eref target="{scheme}://www.rfc-editor.org/info/rfc{rfc_number}" />.
+            </t>""",
             ],
         },
     },
-}
\ No newline at end of file
+}
