@@ -382,6 +382,7 @@ class CachingResolver(lxml.etree.Resolver):
                 xml2rfc.log.note('  retrying %s (%s)' % (url, e.args[0].args[0]))
         else:
             xml2rfc.log.error('Failure fetching URL %s (%s)' % (url, exc.args[0].args[0]))
+            return ''
         for rr in r.history + [r, ]:
             xml2rfc.log.note(' ... %s %s' % (rr.status_code, rr.url))
         if r.status_code == 200:
@@ -509,7 +510,10 @@ class XmlRfcParser:
         # xml root element in lxml: Insert it before we parse:
         text = self.text
         if add_xmlns and not self.nsmap[b'xi'] in text:
-            text = text.replace(b'<rfc ', b'<rfc xmlns:%s="%s" ' % (b'xi', self.nsmap[b'xi']), 1)
+            if re.search(b"""<rfc[^>]*(?P<xi>xmlns:xi=['"][^'"]+['"])""", text):
+                xml2rfc.log.error('Namespace prefix "xi" is defined, but not as the XInclude namespace "%s".' % self.nsmap[b'xi'])
+            else:
+                text = text.replace(b'<rfc ', b'<rfc xmlns:%s="%s" ' % (b'xi', self.nsmap[b'xi']), 1)
 
         # Get an iterating parser object
         file = six.BytesIO(text)
@@ -549,8 +553,6 @@ class XmlRfcParser:
                     self.rfc_number = element.attrib.get("number", None)
                     self.format_version = element.attrib.get("version", None)
                     break
-        except lxml.etree.XMLSyntaxError as e:
-            xml2rfc.log.warn("Parsing Error: %s" % e)
         except ValueError as e:
             if e.message=="I/O operation on closed file":
                 pass
@@ -565,7 +567,7 @@ class XmlRfcParser:
                                       no_network=self.no_network,
                                       remove_comments=remove_comments,
                                       remove_pis=remove_pis,
-                                      remove_blank_text=True,
+                                      remove_blank_text=False,
                                       resolve_entities=True,
                                       strip_cdata=strip_cdata)
 
@@ -621,7 +623,7 @@ class XmlRfcParser:
                                                       no_network=False,
                                                       remove_comments=remove_comments,
                                                       remove_pis=remove_pis,
-                                                      remove_blank_text=True,
+                                                      remove_blank_text=False,
                                                       resolve_entities=True,
                                                       strip_cdata=strip_cdata)
                         parser.set_element_class_lookup(element_lookup)
