@@ -57,6 +57,13 @@ country_alias = {
     "UK": "United Kingdom",
     "Republic of Korea": "Korea, Republic of",
     "South Korea": "Korea, Republic of",
+    "North Korea": "Democratic People's Republic of Korea",
+    "P.R. China": "China",
+    "Åland": "Åland Islands",
+    # Reordering of comma-separated name components:
+    "The Democratic Republic of the Congo": "Congo, The Democratic Republic of the",
+    "State of Palestine": "Palestine, State of",
+    "U.S. Virgin Islands": "Virgin Islands, U.S.",
 }
 
 def get_iso_country_info(e):
@@ -68,7 +75,7 @@ def get_iso_country_info(e):
         name = e.text.strip()
     else:
         return None
-    # Special case, this is used bu unknown to pycountry
+    # Special case, this is used but unknown to pycountry
     if name in country_alias:
         name = country_alias[name]
     try:
@@ -85,11 +92,15 @@ def get_iso_country_info(e):
                 country_info = pycountry.countries.get(name=name.title())
             country_info.alpha_2 = country_info.alpha2
     except LookupError:
-        xml2rfc.log.note("Country lookup failed for %s" % (lxml.etree.tostring(e), ))
+        estr = lxml.etree.tostring(e).replace(b' xmlns:xi="http://www.w3.org/2001/XInclude"', b'').strip().decode('utf-8')
+        if e.tag == 'country':
+            xml2rfc.log.warn("Country lookup failed for %s.  Use --country-help to show recognized country names and codes" % (estr, ))
+        else:
+            xml2rfc.log.note("Country lookup failed for %s.  Use --country-help to show recognized country names and codes" % (estr, ))
         pass
     return country_info
 
-def get_normalized_address_info(writer, x, latin=True):
+def get_normalized_address_info(writer, x, latin=False):
     author = x.getparent().getparent()
     name = full_author_ascii_name(author) if latin else full_author_name(author)
     role = author.get('role')
@@ -100,10 +111,11 @@ def get_normalized_address_info(writer, x, latin=True):
         country_info = get_iso_country_info(country_element)
     if not country_info:
         for c in x.getchildren():
-            country_info = get_iso_country_info(c)
-            if country_info:
-                country_element = c
-                break
+            if c.tag == "postalLine":
+                country_info = get_iso_country_info(c)
+                if country_info:
+                    country_element = c
+                    break
     if country_info:
         country_name = get_value(country_element, latin=latin)
         if country_name in ['US', 'USA']:
@@ -161,7 +173,7 @@ def get_normalized_address_info(writer, x, latin=True):
                 adr['sorting_code'] = value
     for a in adr:
         if isinstance(adr[a], list):
-            adr[a] = ', '.join(adr[a])
+            adr[a] = '\u2028'.join(adr[a])
     if country_info:
         # Address validation
         address_format, rules = get_address_format_rules(adr, latin)
@@ -171,7 +183,7 @@ def get_normalized_address_info(writer, x, latin=True):
         for e in adr:
             if adr[e] and not (e in parts or e in ['name', 'role', 'company_name', 'country_code', ]):
                 list_parts = True
-                writer.note(x, "Postal address part filled in, but not used: %s: %s" % (address_field_elements[e], adr[e]))
+                writer.warn(x, "Postal address part filled in, but not used: %s: %s" % (address_field_elements[e], adr[e]))
         try:
             i18naddress.normalize_address(adr)
         except i18naddress.InvalidAddress as e:
@@ -179,7 +191,7 @@ def get_normalized_address_info(writer, x, latin=True):
             writer.note(x, "Postal address check failed for author %s." % full_author_name(author, latin))
             for item in e.errors:
                 if adr[item]:
-                    writer.note(x, "  Postal address has unexpected address field or field value: %s: %s" % (address_field_elements[item], (adr[item])), label='')
+                    writer.note(x, "  Postal address has an unexpected address field or field value: %s: %s" % (address_field_elements[item], (adr[item])), label='')
                 else:
                     writer.note(x, "  Postal address is missing an address element: %s" % (address_field_elements[item], ), label='')
         if list_parts:
@@ -188,41 +200,19 @@ def get_normalized_address_info(writer, x, latin=True):
 
 # These are copied from i18address in order to remove uppercasing
 
-def _format_address_line(line_format, address, rules):
-    def _get_field(name):
-        value = address.get(name, '')
-        if name == 'name':
-            role = address.get('role', '')
-            if role:
-                value += ' (%s)' % role
-        return value
 
-    replacements = {
-        '%%%s' % code: _get_field(field_name)
-        for code, field_name in address_field_mapping.items()}
-
-    fields = re.split('(%.)', line_format)
-    fields = [replacements.get(f, f) for f in fields]
-    return ''.join(fields).strip()
-
-def get_address_format_rules(address, latin=False):
+def get_address_format_rules(address, latin=False, normalize=False):
     rules = i18naddress.get_validation_rules(address)
-    address_format = (
-        rules.address_latin_format if latin else rules.address_format)
+    address_format = rules.address_latin_format if latin else rules.address_format
+    if rules.address_latin_format != rules.address_format:
+        # don't normalize the line order if the country provides
+        # a latin-specific address format
+        normalize = False
     address_format = enhance_address_format(address, address_format)
+    if normalize:
+        address_format = normalize_address_format(address_format)
     return address_format, rules
 
-def format_address(address, latin=False):
-    def hasword(line):
-        return re.search(r'\w', line, re.U) != None
-    address_format, rules = get_address_format_rules(address, latin)
-    address_line_formats = address_format.split('%n')
-    address_lines = [
-        _format_address_line(lf, address, rules)
-        for lf in address_line_formats]
-    address_lines = filter(hasword, address_lines)
-    return '\n'.join(address_lines)
-
 def enhance_address_format(rules, address_format):
     #     'A': 'street_address'
     #     'C': 'city'
@@ -258,3 +248,36 @@ def enhance_address_format(rules, address_format):
     return address_format
 
     
+def normalize_address_format(address_format):
+    #     'N': 'name'
+    #     'O': 'company_name'
+    #     'E': 'extended_address'
+    #     'A': 'street_address'
+    #     'X': 'sorting_code'
+    #     'D': 'city_area'
+    #     'C': 'city'
+    #     'Z': 'postal_code'
+    #     'S': 'country_area'
+    #     'Y': 'country_name '
+    old = address_format
+    normalized_order = list("NOEAXDCZSY")
+    lines = address_format.split('%n')
+    norm = []
+    # iterate through the desired field order, but don't mess with the address
+    # element order within a line:
+    for code in normalized_order:
+        code = '%'+code
+        found = None
+        for i, line in enumerate(lines):
+            if code in line:
+                norm.append(line)
+                found = i
+                break
+        if found:
+            del lines[found]
+    address_format = '%n'.join(norm)
+    new = address_format
+    if old != new:
+        debug.show('old')
+        debug.show('new')
+    return address_format
