@@ -104,10 +104,13 @@ class TextWrapper(textwrap.TextWrapper):
             wrapped = []
             for part in parts:
                 part = part.lstrip()
-                wrapped += self.wrap(part, initial=initial, subsequent_indent=subsequent_indent,
+                if part:
+                    wrapped += self.wrap(part, initial=initial, subsequent_indent=subsequent_indent,
                                     width=width, fix_doublespace=fix_doublespace,
                                     fix_sentence_endings=fix_sentence_endings,
-                                    drop_whitespace=drop_whitespace)
+                                    drop_whitespace=drop_whitespace) 
+                else:
+                    wrapped.append(part)
             return wrapped
 
         # Set indentation
@@ -618,12 +621,12 @@ def sdict(d):
 
 def isempty(e):
     "Return True if e has no children and no text content"
-    return not ((len(e) and any([ not isinstance(c, _Comment) for c in e.iterchildren() ]))
-                or (e.text and e.text.strip()) or (e.tail and e.tail.strip()))
+    return not (len(e) or (e.text and e.text.strip()) or (e.tail and e.tail.strip()))
 
 def isblock(e):
     "Return True if e is a block level element"
-    return e.tag in [ 'artset', 'artwork', 'dl', 'figure', 'ol', 'sourcecode', 't', 'table', 'ul', 'blockquote', ]
+    from xml2rfc.writers.base import block_tags
+    return e.tag in block_tags
 
 def iscomment(e):
     "Return True if e is a comment"
@@ -635,8 +638,18 @@ def hastext(e):
     items = head + [ c for c in e.iterchildren() if not (isblock(c) or iscomment(c))] + [ c.tail for c in e.iterchildren() if c.tail and c.tail.strip() ]
     return items
 
+def clean_text(s):
+    """Replace internal use code points and various other special code points with plain equivalents"""
+    # spaces
+    s = re.sub(r'[\u00a0\u2028]', ' ', s)
+    # hyphens
+    s = s.replace(r'\u2011', '-')
+    # zero-width
+    s = re.sub(r'[\u200B\u2060\ue060]', '', s)
+    return s.strip()
+
 def is_htmlblock(h):
-    return h.tag in set([ 'address', 'article', 'aside', 'blockquote', 'div', 'dl', 'figure',
-        'h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'nav', 'ol', 'p', 'pre', 'script', 'section',
+    return h.tag in set([ 'address', 'article', 'aside', 'blockquote', 'dd', 'div', 'dl', 'dt', 'figure',
+        'h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'li', 'nav', 'ol', 'p', 'pre', 'script', 'section',
         'table', 'ul', ])
 
