@@ -15,7 +15,7 @@ from lxml.etree import Element, Comment, CDATA
 
 import xml2rfc
 from xml2rfc import log
-from xml2rfc.util.unicode import unicode_content_tags, isascii
+from xml2rfc.util.unicode import unicode_content_tags, unicode_replacements, isascii
 from xml2rfc.utils import hastext, isempty, sdict
 from xml2rfc.writers.base import default_options, BaseV3Writer
 
@@ -275,6 +275,8 @@ class V2v3XmlWriter(BaseV3Writer):
                                             # 2.5.8.  "width" Attribute
                                             # 2.5.9.  "xml:space" Attribute
             './/back',
+            './/code',
+            './/date',
             # We need to process preamble and postamble before figure,
             # because artwork or sourcecode within a figure could later be
             # promoted and the figure discarded.
@@ -313,7 +315,7 @@ class V2v3XmlWriter(BaseV3Writer):
                                             # 2.46.4.  "title" Attribute
             './/*[@anchor]',
             './/xref[@target]',
-            './/processing-instruction()',  # 1.3.2
+            '//processing-instruction()',  # 1.3.2
             # handle mixed block/non-block content surrounding all block nodes
             './/*[self::artwork or self::dl or self::figure or self::ol or self::sourcecode or self::t or self::ul]',
             './/*[@*="yes" or @*="no"]',      # convert old attribute false/true
@@ -377,7 +379,7 @@ class V2v3XmlWriter(BaseV3Writer):
         pi_name = {
             'sortrefs': 'sortRefs',
             'symrefs':  'symRefs',
-            'docdepth': 'tocDepth',
+            'tocdepth': 'tocDepth',
             'toc':      'tocInclude',
         }
         for k, a in pi_name.items():
@@ -385,6 +387,8 @@ class V2v3XmlWriter(BaseV3Writer):
                 v = e.get(k)
                 if v == 'yes':
                     v = 'true'
+                elif v == 'no':
+                    v = 'false'
                 rfc_element.set(a, v)
                 self.replace(e, None, 'Moved %s PI to <rfc %s="%s"' % (k, a, v))
                 break
@@ -493,6 +497,18 @@ class V2v3XmlWriter(BaseV3Writer):
                 refs.append(r)          # moves r
 
 
+    def element_code(self, e, p):
+        if e.text and re.search(r'^[A-Z][A-Z]?-', e.text):
+            cc, num = e.text.split('-', 1)
+            if cc in ['AX', 'CH', 'FI', 'HR', 'FL', 'LT', 'L', 'MC', 'MD', 'SE', 'SI', ]:
+                e.text = num
+
+    def element_date(self, e, p):
+        year = e.get('year')
+        if year and not year.isdigit():
+            del e.attrib['year']
+            e.text = year
+
     # 2.25.  <figure>
     # 
     # 2.25.1.  "align" Attribute
@@ -1130,6 +1146,7 @@ class V2v3XmlWriter(BaseV3Writer):
 #                     c.tail = None
 
     def wrap_non_ascii(self, e, p):
+        self.downcode(replacements=unicode_replacements)
         self.downcode_punctuation()
         for e in self.tree.iter():
             def uwrap(text, line): 
